@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Iller::Configuration;
 
-our $VERSION = '0.1300'; # VERSION
+our $VERSION = '0.1301'; # VERSION
 
 use Dist::Iller::Elk;
 use namespace::autoclean;
@@ -183,14 +183,19 @@ sub add_prereqs_from_configuration {
 
         # Usually only one, but for things like (in weaver) [-Transformer / Lists] we add
         # both Pod::Elemental::Transformer::List and Pod::Weaver::Plugin::Transformer.
+        # if +version is given, only apply it to the first package returned.
+        my $version = $plugin->version;
+        PLUGIN_PACKAGE:
         foreach my $plugin_package ($plugin->plugin_package($other_config->doctype)) {
+            next PLUGIN_PACKAGE if scalar $self->filter_prereqs(sub { $_->module eq $plugin_package });
 
             $self->add_prereq(Dist::Iller::Configuration::Prereq->new(
                 module => $plugin_package,
-                version => 0,
+                version => $version,
                 phase => 'develop',
                 relation => 'requires',
             ));
+            $version = 0;
         }
     }
 }
@@ -212,12 +217,20 @@ sub to_string {
     foreach my $plugin ($self->all_plugins) {
         push @strings => $plugin->to_string, '';
     }
-    my $had_author_deps = 0;
-    foreach my $authordep_module (uniq map { $_->module } $self->filter_prereqs(sub { $_->relation eq 'requires' && $_->module ne 'perl' })) {
-        push @strings => sprintf '; authordep %s', $authordep_module;
-        ++$had_author_deps;
+
+    {
+        my $has_author_deps = 0;
+        my $previous_module = '';
+
+        AUTHORDEP:
+        foreach my $authordep (sort { $a->module cmp $b->module } $self->filter_prereqs(sub { $_->relation eq 'requires' && $_->module ne 'perl' })) {
+            next AUTHORDEP if $authordep->module eq $previous_module;
+            push @strings => sprintf '; authordep %s = %s', $authordep->module, $authordep->version;
+            $has_author_deps = 1;
+            $previous_module = $authordep->module;
+        }
+        push @strings => '' if $has_author_deps;
     }
-    push @strings => '' if $had_author_deps;
 
 
     return join "\n" => @strings;
@@ -239,7 +252,7 @@ Dist::Iller::Configuration
 
 =head1 VERSION
 
-Version 0.1300, released 2016-01-29.
+Version 0.1301, released 2016-02-03.
 
 =head1 SOURCE
 
