@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Iller::Configuration::Plugin;
 
-our $VERSION = '0.1300'; # VERSION
+our $VERSION = '0.1301'; # VERSION
 
 use Dist::Iller::Elk;
 use namespace::autoclean;
@@ -28,6 +28,11 @@ has in => (
     isa => Enum[qw/Plugin PluginBundle Section Elemental/],
     default => 'Plugin',
 );
+has version => (
+    is => 'rw',
+    isa => Str,
+    default => '0',
+);
 has parameters => (
     is => 'ro',
     isa => HashRef,
@@ -146,7 +151,7 @@ Dist::Iller::Configuration::Plugin
 
 =head1 VERSION
 
-Version 0.1300, released 2016-01-29.
+Version 0.1301, released 2016-02-03.
 
 =head1 SOURCE
 
